"""
Data source module for xfintech.

This module provides access to various financial data sources:
- tushare: Tushare Pro API data source with comprehensive A-share market data
- baostock: Baostock data source for alternative market data
"""
